"""Initial Commit

Revision ID: 0bf3d70ee7de
Revises:
Create Date: 2020-05-10 19:02:57.301086

"""

import sqlalchemy as sa

from alembic import op
from sqlalchemy import column, func, table, text
from sqlalchemy.dialects import postgresql


# revision identifiers, used by Alembic.
revision = "0bf3d70ee7de"
down_revision = None
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "clients",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("code", sa.Integer(), nullable=False),
        sa.Column("name", sa.Unicode(length=255), nullable=False),
        sa.Column("enabled", sa.Boolean(), nullable=False),
        sa.Column("otp", sa.Integer(), nullable=True),
        sa.Column("creation_date", sa.DateTime(), nullable=False),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_clients")),
        sa.UniqueConstraint("code", name=op.f("uq_clients_code")),
        sa.UniqueConstraint("name", name=op.f("uq_clients_name")),
    )
    op.create_table(
        "roles",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("name", sa.Unicode(length=255), nullable=True),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_roles")),
        sa.UniqueConstraint("name", name=op.f("uq_roles_name")),
    )
    op.create_table(
        "permissions",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("name", sa.Unicode(length=255), nullable=True),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_permissions")),
        sa.UniqueConstraint("name", name=op.f("uq_permissions_name")),
    )
    op.create_table(
        "users",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("username", sa.Unicode(length=255), nullable=True),
        sa.Column("password", sa.Unicode(length=60), nullable=True),
        sa.Column("disabled", sa.Boolean(), nullable=True),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_users")),
        sa.UniqueConstraint("username", name=op.f("uq_users_username")),
    )
    op.create_table(
        "cost_centres",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("name", sa.Unicode(length=255), nullable=True),
        sa.Column("is_fixture", sa.Boolean(), nullable=False),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_cost_centres")),
        sa.UniqueConstraint("name", name=op.f("uq_cost_centres_name")),
    )
    op.create_table(
        "images",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("resource_id", postgresql.UUID(), nullable=False),
        sa.Column("resource_type", sa.Unicode(length=255), nullable=False),
        sa.Column("image", postgresql.BYTEA(), nullable=False),
        sa.Column("thumbnail", postgresql.BYTEA(), nullable=False),
        sa.Column("creation_date", sa.DateTime(), nullable=False),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_images")),
    )
    op.create_table(
        "product_groups",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("name", sa.Unicode(length=255), nullable=True),
        sa.Column("is_fixture", sa.Boolean(), nullable=False),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_product_groups")),
        sa.UniqueConstraint("name", name=op.f("uq_product_groups_name")),
    )
    setting_type = sa.Enum("VOUCHER_LOCK", name="setting_type")
    # setting_type.create(op.get_bind())
    op.create_table(
        "settings",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("name", sa.Unicode(length=255), nullable=False),
        sa.Column("data", sa.PickleType(), nullable=True),
        sa.Column("setting_type", setting_type, nullable=False),
        sa.Column("valid_from", sa.Date(), nullable=True),
        sa.Column("valid_till", sa.Date(), nullable=True),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_settings")),
        sa.UniqueConstraint("name", name=op.f("uq_settings_name")),
    )
    op.create_table(
        "account_types",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("name", sa.Unicode(length=255), nullable=False),
        sa.Column("balance_sheet", sa.Boolean(), nullable=False),
        sa.Column("debit", sa.Boolean(), nullable=False),
        sa.Column("cash_flow_classification", sa.Unicode(length=255), nullable=False),
        sa.Column("order", sa.Integer(), nullable=False),
        sa.Column("show_in_list", sa.Boolean(), nullable=False),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_account_types")),
        sa.UniqueConstraint("name", name=op.f("uq_account_types_name")),
    )
    op.create_table(
        "accounts",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("code", sa.Integer(), nullable=False),
        sa.Column("name", sa.Unicode(length=255), nullable=False),
        sa.Column("type", sa.Integer(), nullable=False),
        sa.Column("account_type", sa.Unicode(length=50), nullable=False),
        sa.Column("is_starred", sa.Boolean(), nullable=False),
        sa.Column("is_active", sa.Boolean(), nullable=False),
        sa.Column("is_reconcilable", sa.Boolean(), nullable=False),
        sa.Column("cost_centre_id", postgresql.UUID(), nullable=False),
        sa.Column("is_fixture", sa.Boolean(), nullable=False),
        sa.ForeignKeyConstraint(
            ["cost_centre_id"],
            ["cost_centres.id"],
            name=op.f("fk_accounts_cost_centre_id_cost_centres"),
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_accounts")),
        sa.UniqueConstraint("name", name=op.f("uq_accounts_name")),
        sa.ForeignKeyConstraint(
            ["type"],
            ["account_types.id"],
            name=op.f("fk_accounts_type_account_types"),
        ),
    )
    op.create_table(
        "login_history",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("user_id", postgresql.UUID(), nullable=False),
        sa.Column("client_id", postgresql.UUID(), nullable=False),
        sa.Column("date", sa.DateTime(), nullable=False),
        sa.ForeignKeyConstraint(
            ["client_id"],
            ["clients.id"],
            name=op.f("fk_login_history_client_id_clients"),
        ),
        sa.ForeignKeyConstraint(
            ["user_id"],
            ["users.id"],
            name=op.f("fk_login_history_user_id_users"),
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_login_history")),
        sa.UniqueConstraint("user_id", "client_id", "date", name=op.f("uq_login_history_user_id")),
    )
    op.create_table(
        "role_permissions",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("permission_id", postgresql.UUID(), nullable=True),
        sa.Column("role_id", postgresql.UUID(), nullable=True),
        sa.ForeignKeyConstraint(
            ["role_id"],
            ["roles.id"],
            name=op.f("fk_role_permissions_role_id_roles"),
        ),
        sa.ForeignKeyConstraint(
            ["permission_id"],
            ["permissions.id"],
            name=op.f("fk_auth_rolegroups_permission_id_permissions"),
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_role_permissions")),
    )
    op.create_table(
        "user_roles",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("user_id", postgresql.UUID(), nullable=True),
        sa.Column("role_id", postgresql.UUID(), nullable=True),
        sa.ForeignKeyConstraint(
            ["role_id"],
            ["roles.id"],
            name=op.f("fk_user_roles_role_id_roles"),
        ),
        sa.ForeignKeyConstraint(
            ["user_id"],
            ["users.id"],
            name=op.f("fk_user_roles_user_id_users"),
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_user_roles")),
    )
    voucher_type = sa.Enum(
        "JOURNAL",
        "PURCHASE",
        "ISSUE",
        "PAYMENT",
        "RECEIPT",
        "PURCHASE_RETURN",
        "OPENING_ACCOUNTS",
        "OPENING_BATCHES",
        "CLOSING_STOCK",
        "OPENING_BALANCE",
        "CLOSING_BALANCE",
        "EMPLOYEE_BENEFIT",
        "INCENTIVE",
        name="voucher_type",
    )
    # voucher_type.create(op.get_bind())
    op.create_table(
        "vouchers",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("date", sa.DateTime(), nullable=False),
        sa.Column("narration", sa.Unicode(length=1000), nullable=False),
        sa.Column("is_reconciled", sa.Boolean(), nullable=False),
        sa.Column("reconcile_date", sa.DateTime(), nullable=False),
        sa.Column("is_starred", sa.Boolean(), nullable=False),
        sa.Column("creation_date", sa.DateTime(), nullable=False),
        sa.Column("last_edit_date", sa.DateTime(), nullable=False),
        sa.Column("voucher_type", voucher_type, nullable=False),
        sa.Column("user_id", postgresql.UUID(), nullable=False),
        sa.Column("is_posted", sa.Boolean(), nullable=False),
        sa.Column("poster_id", postgresql.UUID(), nullable=True),
        sa.ForeignKeyConstraint(
            ["poster_id"],
            ["users.id"],
            name=op.f("fk_vouchers_poster_id_users"),
        ),
        sa.ForeignKeyConstraint(
            ["user_id"],
            ["users.id"],
            name=op.f("fk_vouchers_user_id_users"),
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_vouchers")),
    )
    op.create_index(op.f("ix_vouchers_date"), "vouchers", ["date"], unique=False)
    op.create_table(
        "employees",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("designation", sa.Unicode(length=255), nullable=True),
        sa.Column("salary", sa.Integer(), nullable=True),
        sa.Column("points", sa.Numeric(precision=5, scale=2), nullable=True),
        sa.Column("joining_date", sa.DateTime(), nullable=False),
        sa.Column("leaving_date", sa.DateTime(), nullable=True),
        sa.ForeignKeyConstraint(["id"], ["accounts.id"], name=op.f("fk_employees_id_accounts")),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_employees")),
    )
    op.create_table(
        "journals",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("debit", sa.Integer(), nullable=False),
        sa.Column("amount", sa.Numeric(precision=15, scale=2), nullable=False),
        sa.Column("voucher_id", postgresql.UUID(), nullable=False),
        sa.Column("account_id", postgresql.UUID(), nullable=False),
        sa.Column("cost_centre_id", postgresql.UUID(), nullable=False),
        sa.ForeignKeyConstraint(
            ["cost_centre_id"],
            ["cost_centres.id"],
            name=op.f("fk_journals_cost_centre_id_cost_centres"),
        ),
        sa.ForeignKeyConstraint(
            ["voucher_id"],
            ["vouchers.id"],
            name=op.f("fk_journals_voucher_id_vouchers"),
        ),
        sa.ForeignKeyConstraint(
            ["account_id"],
            ["accounts.id"],
            name=op.f("fk_journals_account_id_accounts"),
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_journals")),
    )
    op.create_index(op.f("ix_journals_voucher_id"), "journals", ["voucher_id"], unique=False)
    op.create_table(
        "products",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("code", sa.Integer(), nullable=True),
        sa.Column("name", sa.Unicode(length=255), nullable=False),
        sa.Column("fraction_units", sa.Unicode(length=255), nullable=False),
        sa.Column("product_group_id", postgresql.UUID(), nullable=False),
        sa.Column("account_id", postgresql.UUID(), nullable=False),
        sa.Column("is_active", sa.Boolean(), nullable=False),
        sa.Column("is_fixture", sa.Boolean(), nullable=False),
        sa.Column("is_purchased", sa.Boolean(), nullable=False),
        sa.Column("is_sold", sa.Boolean(), nullable=False),
        sa.ForeignKeyConstraint(
            ["product_group_id"],
            ["product_groups.id"],
            name=op.f("fk_products_product_group_id_product_groups"),
        ),
        sa.ForeignKeyConstraint(
            ["account_id"],
            ["accounts.id"],
            name=op.f("fk_products_account_id_accounts"),
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_products")),
        sa.UniqueConstraint("code", name=op.f("uq_products_code")),
        sa.UniqueConstraint("name", name=op.f("uq_products_name")),
    )
    op.create_table(
        "stock_keeping_units",
        sa.Column("id", postgresql.UUID(as_uuid=True), nullable=False),
        sa.Column("product_id", postgresql.UUID(as_uuid=True), nullable=False),
        sa.Column("units", sa.Unicode(length=255), nullable=False),
        sa.Column("fraction", sa.Numeric(precision=15, scale=5), nullable=False),
        sa.Column("product_yield", sa.Numeric(precision=15, scale=5), nullable=False),
        sa.Column("cost_price", sa.Numeric(precision=15, scale=2), nullable=False),
        sa.Column("sale_price", sa.Numeric(precision=15, scale=2), nullable=False),
        sa.ForeignKeyConstraint(
            ["product_id"], ["products.id"], name=op.f("fk_stock_keeping_units_product_id_products")
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_stock_keeping_units")),
        sa.UniqueConstraint("product_id", "units", name=op.f("uq_stock_keeping_units_product_id")),
    )
    op.create_table(
        "attendances",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("employee_id", postgresql.UUID(), nullable=True),
        sa.Column("date", sa.DateTime(), nullable=True),
        sa.Column("attendance_type", sa.Integer(), nullable=True),
        sa.Column("amount", sa.Numeric(precision=15, scale=5), nullable=False),
        sa.Column("creation_date", sa.DateTime(), nullable=False),
        sa.Column("user_id", postgresql.UUID(), nullable=True),
        sa.Column("is_valid", sa.Boolean(), nullable=True),
        sa.ForeignKeyConstraint(
            ["employee_id"],
            ["employees.id"],
            name=op.f("fk_attendances_employee_id_employees"),
        ),
        sa.ForeignKeyConstraint(
            ["user_id"],
            ["users.id"],
            name=op.f("fk_attendances_user_id_users"),
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_attendances")),
    )
    op.create_index(
        "only_one_valid_attendance",
        "attendances",
        ["employee_id", "date"],
        unique=True,
        postgresql_where=sa.text("is_valid = true"),
    )
    op.create_table(
        "batches",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("name", sa.DateTime(), nullable=False),
        sa.Column("sku_id", postgresql.UUID(), nullable=False),
        sa.Column("quantity_remaining", sa.Numeric(precision=15, scale=2), nullable=False),
        sa.Column("rate", sa.Numeric(precision=15, scale=2), nullable=False),
        sa.Column("tax", sa.Numeric(precision=15, scale=5), nullable=False),
        sa.Column("discount", sa.Numeric(precision=15, scale=5), nullable=False),
        sa.ForeignKeyConstraint(
            ["sku_id"],
            ["stock_keeping_units.id"],
            name=op.f("fk_batches_sku_id_stock_keeping_units"),
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_batches")),
    )
    op.create_table(
        "fingerprints",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("employee_id", postgresql.UUID(), nullable=True),
        sa.Column("date", sa.DateTime(), nullable=True),
        sa.ForeignKeyConstraint(
            ["employee_id"],
            ["employees.id"],
            name=op.f("fk_fingerprints_employee_id_employees"),
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_fingerprints")),
        sa.UniqueConstraint("employee_id", "date", name=op.f("uq_fingerprints_employee_id")),
    )
    op.create_table(
        "periods",
        sa.Column("id", postgresql.UUID(as_uuid=True), nullable=False),
        sa.Column("valid_from", sa.Date(), nullable=False),
        sa.Column("valid_till", sa.Date(), nullable=False),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_periods")),
    )
    p = table(
        "periods",
        column("id", postgresql.UUID()),
        column("valid_from", sa.Date()),
        column("valid_till", sa.Date()),
    )
    op.create_exclude_constraint(
        "uq_periods_valid_from",
        "periods",
        (func.daterange(p.c.valid_from, p.c.valid_till, text("'[]'")), "&&"),
    )
    op.create_table(
        "recipes",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("sku_id", postgresql.UUID(), nullable=False),
        sa.Column("recipe_yield", sa.Numeric(precision=15, scale=2), nullable=False),
        sa.Column("cost_price", sa.Numeric(precision=15, scale=2), nullable=False),
        sa.Column("sale_price", sa.Numeric(precision=15, scale=2), nullable=False),
        sa.Column("notes", sa.Unicode(length=255), nullable=True),
        sa.Column("period_id", postgresql.UUID(as_uuid=True), nullable=False),
        sa.ForeignKeyConstraint(
            ["sku_id"],
            ["stock_keeping_units.id"],
            name=op.f("fk_recipes_sku_id_stock_keeping_units"),
        ),
        sa.ForeignKeyConstraint(
            ["period_id"],
            ["periods.id"],
            name=op.f("fk_recipes_period_id_periods"),
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_recipes")),
        sa.UniqueConstraint("sku_id", "period_id", name=op.f("uq_recipes_sku_id")),
    )
    op.create_table(
        "employee_benefit",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("voucher_id", postgresql.UUID(), nullable=False),
        sa.Column("journal_id", postgresql.UUID(), nullable=False),
        sa.Column("gross_salary", sa.Integer(), nullable=True),
        sa.Column("days_worked", sa.Integer(), nullable=True),
        sa.Column("esi_employee", sa.Integer(), nullable=True),
        sa.Column("pf_employee", sa.Integer(), nullable=True),
        sa.Column("esi_employer", sa.Integer(), nullable=True),
        sa.Column("pf_employer", sa.Integer(), nullable=True),
        sa.ForeignKeyConstraint(
            ["journal_id"],
            ["journals.id"],
            name=op.f("fk_employee_benefit_journal_id_journals"),
        ),
        sa.ForeignKeyConstraint(
            ["voucher_id"],
            ["vouchers.id"],
            name=op.f("fk_employee_benefit_voucher_id_vouchers"),
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_employee_benefit")),
    )
    op.create_table(
        "incentives",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("voucher_id", postgresql.UUID(), nullable=False),
        sa.Column("journal_id", postgresql.UUID(), nullable=False),
        sa.Column("days_worked", sa.Numeric(precision=5, scale=1), nullable=False),
        sa.Column("points", sa.Numeric(precision=5, scale=2), nullable=False),
        sa.ForeignKeyConstraint(
            ["journal_id"],
            ["journals.id"],
            name=op.f("fk_incentives_journal_id_journals"),
        ),
        sa.ForeignKeyConstraint(
            ["voucher_id"],
            ["vouchers.id"],
            name=op.f("fk_incentives_voucher_id_vouchers"),
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_incentives")),
    )
    op.create_table(
        "inventories",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("voucher_id", postgresql.UUID(), nullable=False),
        sa.Column("batch_id", postgresql.UUID(), nullable=False),
        sa.Column("quantity", sa.Numeric(precision=15, scale=2), nullable=False),
        sa.Column("rate", sa.Numeric(precision=15, scale=2), nullable=False),
        sa.Column("tax", sa.Numeric(precision=15, scale=5), nullable=False),
        sa.Column("discount", sa.Numeric(precision=15, scale=5), nullable=False),
        sa.ForeignKeyConstraint(
            ["batch_id"],
            ["batches.id"],
            name=op.f("fk_inventories_batch_id_batches"),
        ),
        sa.ForeignKeyConstraint(
            ["voucher_id"],
            ["vouchers.id"],
            name=op.f("fk_inventories_voucher_id_vouchers"),
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_inventories")),
        sa.UniqueConstraint("voucher_id", "batch_id", name=op.f("uq_inventories_voucher_id")),
    )
    op.create_index(op.f("ix_inventories_voucher_id"), "inventories", ["voucher_id"], unique=False)
    op.create_table(
        "recipe_items",
        sa.Column("id", postgresql.UUID(), nullable=False),
        sa.Column("recipe_id", postgresql.UUID(), nullable=False),
        sa.Column("product_id", postgresql.UUID(), nullable=False),
        sa.Column("quantity", sa.Numeric(precision=15, scale=2), nullable=False),
        sa.Column("price", sa.Numeric(precision=15, scale=2), nullable=False),
        sa.ForeignKeyConstraint(
            ["product_id"],
            ["products.id"],
            name=op.f("fk_recipe_items_product_id_products"),
        ),
        sa.ForeignKeyConstraint(
            ["recipe_id"],
            ["recipes.id"],
            name=op.f("fk_recipe_items_recipe_id_recipes"),
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_recipe_items")),
        sa.UniqueConstraint("recipe_id", "product_id", name=op.f("uq_recipe_items_recipe_id")),
    )
    op.create_table(
        "rate_contracts",
        sa.Column("id", postgresql.UUID(as_uuid=True), nullable=False),
        sa.Column("date", sa.Date(), nullable=False),
        sa.Column("vendor_id", postgresql.UUID(as_uuid=True), nullable=False),
        sa.Column("valid_from", sa.Date(), nullable=True),
        sa.Column("valid_till", sa.Date(), nullable=True),
        sa.Column("narration", sa.Unicode(length=1000), nullable=False),
        sa.Column("user_id", postgresql.UUID(as_uuid=True), nullable=False),
        sa.Column("creation_date", sa.DateTime(), nullable=False),
        sa.Column("last_edit_date", sa.DateTime(), nullable=False),
        sa.ForeignKeyConstraint(["user_id"], ["users.id"], name=op.f("fk_rate_contracts_user_id_users")),
        sa.ForeignKeyConstraint(["vendor_id"], ["accounts.id"], name=op.f("fk_rate_contracts_vendor_id_accounts")),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_rate_contracts")),
    )
    op.create_index(op.f("ix_rate_contracts_date"), "rate_contracts", ["date"], unique=False)
    op.create_table(
        "rate_contract_items",
        sa.Column("id", postgresql.UUID(as_uuid=True), nullable=False),
        sa.Column("rate_contract_id", postgresql.UUID(as_uuid=True), nullable=False),
        sa.Column("sku_id", postgresql.UUID(as_uuid=True), nullable=False),
        sa.Column("cost_price", sa.Numeric(precision=15, scale=2), nullable=False),
        sa.ForeignKeyConstraint(
            ["sku_id"], ["stock_keeping_units.id"], name=op.f("fk_rate_contract_items_sku_id_stock_keeping_units")
        ),
        sa.ForeignKeyConstraint(
            ["rate_contract_id"],
            ["rate_contracts.id"],
            name=op.f("fk_rate_contract_items_rate_contract_id_rate_contracts"),
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_rate_contract_items")),
        sa.UniqueConstraint("rate_contract_id", "sku_id", name=op.f("uq_rate_contract_items_rate_contract_id")),
    )
    op.create_index(
        op.f("ix_rate_contract_items_rate_contract_id"), "rate_contract_items", ["rate_contract_id"], unique=False
    )
    op.create_table(
        "closing_stocks",
        sa.Column("id", postgresql.UUID(as_uuid=True), nullable=False),
        sa.Column("date", sa.Date(), nullable=False),
        sa.Column("cost_centre_id", postgresql.UUID(as_uuid=True), nullable=False),
        sa.Column("sku_id", postgresql.UUID(as_uuid=True), nullable=False),
        sa.Column("quantity", sa.Numeric(precision=15, scale=2), nullable=False),
        sa.ForeignKeyConstraint(
            ["cost_centre_id"], ["cost_centres.id"], name=op.f("fk_closing_stocks_cost_centre_id_cost_centres")
        ),
        sa.ForeignKeyConstraint(
            ["sku_id"], ["stock_keeping_units.id"], name=op.f("fk_closing_stocks_sku_id_stock_keeping_units")
        ),
        sa.PrimaryKeyConstraint("id", name=op.f("pk_closing_stocks")),
        sa.UniqueConstraint("date", "cost_centre_id", "sku_id", name=op.f("uq_closing_stocks_date")),
    )


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    pass
    # ### end Alembic commands ###
