import datetime
import uuid

from typing import TYPE_CHECKING, List, Optional

from sqlalchemy import Column, Date, func, text
from sqlalchemy.dialects import postgresql
from sqlalchemy.dialects.postgresql import UUID
from sqlalchemy.orm import relationship

from ..db.base_class import Base


if TYPE_CHECKING:
    # if the target of the relationship is in another module
    # that cannot normally be imported at runtime
    from .recipe import Recipe


class Period(Base):
    __tablename__ = "periods"

    id: uuid.UUID = Column("id", UUID(as_uuid=True), primary_key=True, default=uuid.uuid4)
    valid_from: datetime.date = Column("valid_from", Date, nullable=False)
    valid_till: datetime.date = Column("valid_till", Date, nullable=False)

    __table_args__ = (
        postgresql.ExcludeConstraint(
            (func.daterange(valid_from, valid_till, text("'[]'")), "&&"),
        ),
    )
    recipes: List["Recipe"] = relationship("Recipe", back_populates="period")

    def __init__(
        self,
        valid_from: datetime.date,
        valid_till: datetime.date,
        id_: Optional[uuid.UUID] = None,
    ) -> None:
        self.valid_from = valid_from
        self.valid_till = valid_till
        if id_ is not None:
            self.id = id_
