from typing import List

import brewman.schemas.account_type as schemas

from fastapi import APIRouter, Depends
from sqlalchemy import select

from ..core.security import get_current_active_user as get_user
from ..db.session import SessionFuture
from ..models.account_type import AccountType
from ..schemas.user import UserToken


router = APIRouter()


@router.get("", response_model=List[schemas.AccountType])
def account_type_list(user: UserToken = Depends(get_user)) -> List[schemas.AccountType]:
    with SessionFuture() as db:
        return [
            schemas.AccountType(id=item.id, name=item.name) for item in db.execute(select(AccountType)).scalars().all()
        ]
