from datetime import date, datetime
from decimal import Decimal
from typing import List, Optional, Union

from pydantic import validator
from pydantic.main import BaseModel

from . import to_camel


class BalanceSheetItem(BaseModel):
    name: Optional[str]
    group: Optional[str]
    amount: Optional[Decimal]
    sub_amount: Optional[Decimal]
    order: int

    class Config:
        anystr_strip_whitespace = True
        alias_generator = to_camel


class BalanceSheet(BaseModel):
    date_: date
    body: List[BalanceSheetItem]
    footer: Optional[BalanceSheetItem]

    class Config:
        anystr_strip_whitespace = True
        alias_generator = to_camel
        json_encoders = {date: lambda v: v.strftime("%d-%b-%Y")}

    @validator("date_", pre=True)
    def parse_date(cls, value: Union[date, str]) -> date:
        if isinstance(value, date):
            return value
        return datetime.strptime(value, "%d-%b-%Y").date()
