from datetime import date, datetime
from decimal import Decimal
from typing import List, Union

from pydantic import validator
from pydantic.main import BaseModel

from . import to_camel


class NonContractPurchase(BaseModel):
    date_: date
    vendor: str
    product: str
    url: List[str]
    contract_price: Decimal
    purchase_price: Decimal

    class Config:
        anystr_strip_whitespace = True
        alias_generator = to_camel
        json_encoders = {date: lambda v: v.strftime("%d-%b-%Y")}

    @validator("date_", pre=True)
    def parse_start_date(cls, value: Union[date, str]) -> date:
        if isinstance(value, date):
            return value
        return datetime.strptime(value, "%d-%b-%Y").date()
